@@ -5,7 +5,7 @@ use warnings;
 package Story::Interact::Page;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001010';
+our $VERSION   = '0.001011';
 
 use Moo;
 use Types::Common -types;
@@ -74,4 +74,11 @@ sub add_next_page {
 	return;
 }
 
+sub reset_next_pages {
+	my $self = shift;
+	my @r = @{ $self->next_pages };
+	@{ $self->next_pages } = ();
+	return \@r;
+}
+
 1;
